==> koffice-1.2.1.tar.bz2: koffice-1.2.1/kword/stylenames.cc <==
/* This file is part of the KDE project
   Copyright (C) 2001 David Faure <faure@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA
*/

// This file provides translations for the standard style names
i18n( "Style name", "Standard" );
i18n( "Style name", "Head 1" );
i18n( "Style name", "Head 2" );
i18n( "Style name", "Head 3" );
i18n( "Style name", "Enumerated List" );
i18n( "Style name", "Alphabetical List" );
i18n( "Style name", "Bullet List" );
i18n( "Style name", "Contents Title" );
i18n( "Style name", "Contents Head 1" );
i18n( "Style name", "Contents Head 2" );
i18n( "Style name", "Contents Head 3" );
i18n( "Style name", "Document Title" );
i18n( "Style name", "Header" );
i18n( "Style name", "Footer" );

// Translations for the standard framestyle names
i18n( "Style name", "Plain" );
i18n( "Style name", "Borders 1" );
i18n( "Style name", "Borders 2" );
i18n( "Style name", "Borders 3" );
i18n( "Style name", "Row" );
i18n( "Style name", "Column" );
i18n( "Style name", "Light gray" );
i18n( "Style name", "Dark gray" );
i18n( "Style name", "Black" );
i18n( "Style name", "Light blue" );
i18n( "Style name", "Dark blue" );
i18n( "Style name", "Red" );
i18n( "Style name", "Yellow" );
i18n( "Style name", "Colorful" );
i18n( "Style name", "Blueish" );

// Translations for the standard tablestyle names
i18n( "Style name", "Simple 1" );
i18n( "Style name", "Simple 2" );
i18n( "Style name", "Simple 3" );
i18n( "Style name", "Header 1" );
i18n( "Style name", "Header 2" );
i18n( "Style name", "Header 3" );
i18n( "Style name", "Header 4" );
      
// Translations for the standard tabletemplate names
i18n( "Style name", "Grid 1" );
i18n( "Style name", "Grid 2" );
i18n( "Style name", "Grid 3" );
i18n( "Style name", "Gray heading" );
i18n( "Style name", "Blue heading" );
i18n( "Style name", "Blue traditional" );
i18n( "Style name", "Gray traditional" );
i18n( "Style name", "Blue top and bottom" );
i18n( "Style name", "Gray top and bottom" );

==> koffice-1.3.1.tar.bz2: koffice-1.3.1/kword/stylenames.cc <==
/* This file is part of the KDE project
   Copyright (C) 2001 David Faure <faure@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA
*/

// This file provides translations for the standard style names
i18n( "Style name", "Standard" );
i18n( "Style name", "Head 1" );
i18n( "Style name", "Head 2" );
i18n( "Style name", "Head 3" );
i18n( "Style name", "Enumerated List" );
i18n( "Style name", "Alphabetical List" );
i18n( "Style name", "Bullet List" );
i18n( "Style name", "Contents Title" );
i18n( "Style name", "Contents Head 1" );
i18n( "Style name", "Contents Head 2" );
i18n( "Style name", "Contents Head 3" );
i18n( "Style name", "Document Title" );
i18n( "Style name", "Header" );
i18n( "Style name", "Footer" );

// Translations for the standard framestyle names
i18n( "Style name", "Plain" );
i18n( "Style name", "Borders 1" );
i18n( "Style name", "Borders 2" );
i18n( "Style name", "Borders 3" );
i18n( "Style name", "Row" );
i18n( "Style name", "Column" );
i18n( "Style name", "Light Gray" );
i18n( "Style name", "Dark Gray" );
i18n( "Style name", "Black" );
i18n( "Style name", "Light Blue" );
i18n( "Style name", "Dark Blue" );
i18n( "Style name", "Red" );
i18n( "Style name", "Yellow" );
i18n( "Style name", "Colorful" );
i18n( "Style name", "Blueish" );

// Translations for the standard tablestyle names
i18n( "Style name", "Simple 1" );
i18n( "Style name", "Simple 2" );
i18n( "Style name", "Simple 3" );
i18n( "Style name", "Header 1" );
i18n( "Style name", "Header 2" );
i18n( "Style name", "Header 3" );
i18n( "Style name", "Header 4" );

// Translations for the standard tabletemplate names
i18n( "Style name", "Grid 1" );
i18n( "Style name", "Grid 2" );
i18n( "Style name", "Grid 3" );
i18n( "Style name", "Gray Heading" );
i18n( "Style name", "Blue Heading" );
i18n( "Style name", "Blue Traditional" );
i18n( "Style name", "Gray Traditional" );
i18n( "Style name", "Blue Top and Bottom" );
i18n( "Style name", "Gray Top and Bottom" );
